==> squidwall-0.3b.tar.bz2: squidwall-0.3b/squidwall.h <==
#ifndef SW_SQUIDWALL_H
#define SW_SQUIDWALL_H

#include "params.h"

/* system */
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/types.h>
#include <sys/time.h>
#include <sys/stat.h>
#include <sys/poll.h>
#include <sys/time.h>
#include <unistd.h>
#include <string.h>
#include <stdlib.h>
#include <dirent.h>
#include <regex.h>
#include <fcntl.h>
#include <errno.h>
#include <wait.h>
#include <time.h>

/* libowfat */
#include "array.h"
#include "buffer.h"
#include "case.h"
#include "fmt.h"
#include "ip4.h"
#include "ip6.h"
#include "io.h"
#include "str.h"
#include "scan.h"
#include "socket.h"
#include "stralloc.h"
#include "textcode.h"

/* squidwall */
#include "debug.h"
#include "env.h"
#include "log.h"
#include "list.h"

struct ip_address { unsigned char d[4]; };

/* type of acl directories */
#define TYPE_ACL      0
#define TYPE_STRING   1
#define TYPE_REGEX    2
#define TYPE_PHRASE   3

/* hosts/ip's + users */
struct squidwall_acl {
	struct list_head list;     /* the list with all elements */
	stralloc filename;         /* without the '?' prefix */

	int flags;                 /* ACL_(ALLOW|FILTER|DENY) */
#define ACL_NONE      0
#define ACL_ALLOW     1
#define ACL_FILTER    2
#define ACL_DENY      4
#define ACL_DEFAULT   ACL_ALLOW

	int todo;                  /* TODO_(NONE|VIRUS|CONT...) */
#define TODO_NONE        0
#define TODO_URL         1
#define TODO_URLr        2
#define TODO_VIRUS       4
#define TODO_CONT        8
#define TODO_CONTr      16
#define TODO_PHRASE     32
#define TODO_BAN        64
#define TODO_BANr      128
#define TODO_BANc      256
#define TODO_WLST      512
#define TODO_WLSTr    1024

/* per default, all files of all filters are used! */
#define TODO_DEFAULT (1|2|4|8|16|32|64|128|256|512|1024)

	/* filter which redirect to a denypage */
	stralloc pfilter;   /* +p / -p */
	stralloc cfilter;   /* +c / -c */
	stralloc crfilter;  /* +C / -C */
	stralloc ufilter;   /* +u / -u */
	stralloc urfilter;  /* +U / -U */

	/* filter which redirect to an empty image file */
	stralloc bfilter;   /* +b / -b */
	stralloc bcfilter;  /* +a / -a */
	stralloc brfilter;  /* +B / -B */

	/* whitelists */
	stralloc wfilter;   /* +w / -w */
	stralloc wrfilter;  /* +W / -W */
};

/* ufilter + cfilter */
struct squidwall_string {
	struct list_head list;  /* the list with all elements */
	stralloc filename;      /* just the filename of the filters */
	stralloc strings;       /* all strings from filename */
};

/* pfilter */
struct squidwall_phrase {
	struct list_head list;  /* the list with all elements */
	stralloc filename;      /* just the filename of the phrase filters */
	stralloc strings;       /* all string:hitpoint pairs from filename */
	array points;           /* array of type 'unsigned int' (0..255) */
};

/* urfilter + crfilter */
struct squidwall_regex {
	struct list_head list;  /* the list with all elements */
	stralloc filename;      /* just the filename of the regex filters */
	array regex;            /* array of type 'struct named_regex' */
};

struct named_regex {
	stralloc n;  /* the string, which defines the regex */
	regex_t r;   /* the precompiled regex */
	int cflags;
	int eflags;
};

/* fd of logfile */
extern int64 fd_log;

/* ip's and ports */
extern struct ip_address clamd_ip;
extern struct ip_address proxy_ip;
extern unsigned clamd_port;
extern unsigned clams_port;
extern unsigned proxy_port;

/* max size for content/virus scanning */
extern unsigned int maxsize;
extern unsigned int pfilter_max;

/* pointer to the infos from squid @ fd=0 */
extern char *squid_url;
extern char *squid_ip;
extern char *squid_host;
extern char *squid_user;
extern char *squid_method;

/* lists */
extern struct list_head hosts;
extern struct list_head users;
extern struct list_head bfilter;
extern struct list_head bcfilter;
extern struct list_head brfilter;
extern struct list_head cfilter;
extern struct list_head crfilter;
extern struct list_head pfilter;
extern struct list_head ufilter;
extern struct list_head urfilter;
extern struct list_head wfilter;
extern struct list_head wrfilter;

/* defined filters of current ip / host */
extern stralloc *bfilter_host;
extern stralloc *bcfilter_host;
extern stralloc *brfilter_host;
extern stralloc *cfilter_host;
extern stralloc *crfilter_host;
extern stralloc *pfilter_host;
extern stralloc *ufilter_host;
extern stralloc *urfilter_host;
extern stralloc *wfilter_host;
extern stralloc *wrfilter_host;

/* defined filters of current user */
extern stralloc *bfilter_user;
extern stralloc *bcfilter_user;
extern stralloc *brfilter_user;
extern stralloc *cfilter_user;
extern stralloc *crfilter_user;
extern stralloc *pfilter_user;
extern stralloc *ufilter_user;
extern stralloc *urfilter_user;
extern stralloc *wfilter_user;
extern stralloc *wrfilter_user;

/* destination websites for squid */
extern char *redir_badurl;
extern char *redir_badcont;
extern char *redir_baduser;
extern char *redir_badhost;
extern char *redir_safesite;
extern char *redir_virusfound;
extern char *redir_bannerfound;
extern char *redir_webinterface;

/* misc directories */
extern char *host_dir;
extern char *user_dir;
extern char *bfilter_dir;
extern char *bcfilter_dir;
extern char *brfilter_dir;
extern char *cfilter_dir;
extern char *crfilter_dir;
extern char *pfilter_dir;
extern char *ufilter_dir;
extern char *urfilter_dir;
extern char *wfilter_dir;
extern char *wrfilter_dir;

/* decoded infos */
extern stralloc ip;
extern stralloc url;
extern stralloc host;
extern stralloc user;
extern stralloc method;
extern stralloc redirsite;

/* panic.c */
extern int panic(char *msg);

/* check_...c */
extern int check_host(int *todo);
extern int check_user(int *todo);
extern int check_wlist(void);
extern int check_banner(void);
extern int check_url(void);
extern int check_cont(int todo);

/* case_strstr.c -> 1=>found | 0=>not found */
extern int case_strstr(const char *haystack, const char *needle);

/* redir_site.c */
#define REDIR_TYPE_USER    0 /* user not okay */
#define REDIR_TYPE_HOST    1 /* host not okay */
#define REDIR_TYPE_URL     2 /* url not okay */
#define REDIR_TYPE_CONT    4 /* content not okay */
#define REDIR_TYPE_VIRUS   8 /* virus found */
#define REDIR_TYPE_BANNER 16 /* banner found */
#define REDIR_TYPE_CONFIG 32 /* webinterface */
extern void redir_site(int type);

#define isset(v,x)     (((v)&(x)) == (x))
#define set(v,x)       (v) |=  (x)
#define unset(v,x)     (v) &= ~(x)

/* read_acls.c */
extern void read_acls(void);

/* array's of type struct squidwall_regex */
extern array array_bcfilter_todo;
extern array array_cfilter_todo;
extern array array_pfilter_todo;

/* read_filters.c */
extern void read_filters(struct squidwall_acl *acl, const char *path, const char *file);

#endif

==> squidwall-0.4.tar.bz2: squidwall-0.4/squidwall.h <==
#ifndef SW_SQUIDWALL_H
#define SW_SQUIDWALL_H

/**
 * Copyright (C) 2005-2006 Tino Reichardt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "params.h"

#define VERSION    "squidwall 0.4"

#define BUFSIZE    5000

/* system */
#include <sys/socket.h>
#include <sys/types.h>
#include <sys/types.h>
#include <sys/time.h>
#include <sys/stat.h>
#include <sys/poll.h>
#include <sys/time.h>
#include <sys/un.h>
#include <unistd.h>
#include <string.h>
#include <stdlib.h>
#include <dirent.h>
#include <regex.h>
#include <fcntl.h>
#include <errno.h>
#include <wait.h>
#include <time.h>

/* libowfat */
#include "array.h"
#include "buffer.h"
#include "case.h"
#include "fmt.h"
#include "ip4.h"
#include "ip6.h"
#include "io.h"
#include "str.h"
#include "scan.h"
#include "socket.h"
#include "stralloc.h"
#include "textcode.h"

/* squidwall */
#include "debug.h"
#include "env.h"
#include "log.h"
#include "list.h"

struct ip_address { unsigned char d[4]; };

/* type of acl directories */
#define TYPE_ACL      0
#define TYPE_STRING   1
#define TYPE_REGEX    2
#define TYPE_PHRASE   3
#define TYPE_REDIRECT 4

/* hosts/ip's + users */
struct squidwall_acl {
	struct list_head list;     /* the list with all elements */
	stralloc filename;         /* without the '?' prefix */

	int flags;                 /* ACL_(ALLOW|FILTER|DENY) */
#define ACL_NONE      0
#define ACL_ALLOW     1
#define ACL_FILTER    2
#define ACL_DENY      4
#define ACL_DEFAULT   ACL_ALLOW

	int todo;                  /* TODO_(NONE|VIRUS|CONT...) */
#define TODO_NONE        0
#define TODO_PHRASE      1
#define TODO_CONT        2
#define TODO_CONTr       4
#define TODO_URL         8
#define TODO_URLr       16
#define TODO_URLmd5     32
#define TODO_URLsha1    64
#define TODO_BAN       128
#define TODO_BANr      256
#define TODO_BANc      512
#define TODO_WLST     1024
#define TODO_WLSTr    2048
#define TODO_VIRUS    4096

/* per default, all files of all filters are used! */
#define TODO_DEFAULT (1|2|4|8|16|32|64|128|256|512|1024|2048|4096)

	/* filter which redirect to a denypage */
	stralloc pfilter;      /* +p / -p */
	stralloc cfilter;      /* +c / -c */
	stralloc crfilter;     /* +C / -C */
	stralloc ufilter;      /* +u / -u */
	stralloc ufilter_md5;  /* +m / -m */
	stralloc ufilter_sha1; /* +s / -s */
	stralloc urfilter;     /* +U / -U */

	/* filter which redirect to an empty image file */
	stralloc bfilter;      /* +b / -b */
	stralloc bcfilter;     /* +a / -a */
	stralloc brfilter;     /* +B / -B */

	/* whitelists */
	stralloc wfilter;      /* +w / -w */
	stralloc wrfilter;     /* +W / -W */
};

/* bfilter, ufilter, cfilter, ufilter_md5, ufilter_sha1, wfilter  */
struct squidwall_string {
	struct list_head list;  /* the list with all elements */
	stralloc filename;      /* just the filename of the filters */
	stralloc strings;       /* all strings from filename */
};

/* pfilter */
struct squidwall_phrase {
	struct list_head list;  /* the list with all elements */
	stralloc filename;      /* just the filename of the phrase filters */
	stralloc strings;       /* all string:hitpoint pairs from filename */
	array points;           /* array of type 'unsigned int' (0..255) */
};

/* bcfilter, brfilter, urfilter, crfilter, wrfilter */
struct squidwall_regex {
	struct list_head list;  /* the list with all elements */
	stralloc filename;      /* just the filename of the regex filters */
	array regex;            /* array of type 'struct named_regex' */
};

struct named_regex {
	stralloc n;  /* the string, which defines the regex */
	regex_t r;   /* the precompiled regex */
	int cflags;
	int eflags;
};

/* fd of logfile */
extern int64 fd_log;

/* ip's and ports */
extern struct ip_address clamd_ip;
extern struct ip_address proxy_ip;
extern unsigned clamd_port;
extern unsigned clams_port;
extern unsigned proxy_port;

/* max size for content/virus scanning */
extern unsigned int maxsize;
extern unsigned int pfilter_max;

/* pointer to the infos from squid @ fd=0 */
extern char *squid_url;
extern char *squid_ip;
extern char *squid_host;
extern char *squid_user;
extern char *squid_method;

/* lists */
extern struct list_head hosts;
extern struct list_head users;
extern struct list_head redirects;
extern struct list_head bfilter;
extern struct list_head bcfilter;
extern struct list_head brfilter;
extern struct list_head cfilter;
extern struct list_head crfilter;
extern struct list_head pfilter;
extern struct list_head ufilter;
extern struct list_head ufilter_md5;
extern struct list_head ufilter_sha1;
extern struct list_head urfilter;
extern struct list_head wfilter;
extern struct list_head wrfilter;

/* defined filters of current ip / host */
extern stralloc *bfilter_host;
extern stralloc *bcfilter_host;
extern stralloc *brfilter_host;
extern stralloc *cfilter_host;
extern stralloc *crfilter_host;
extern stralloc *pfilter_host;
extern stralloc *ufilter_host;
extern stralloc *ufilter_md5_host;
extern stralloc *ufilter_sha1_host;
extern stralloc *urfilter_host;
extern stralloc *wfilter_host;
extern stralloc *wrfilter_host;

/* defined filters of current user */
extern stralloc *bfilter_user;
extern stralloc *bcfilter_user;
extern stralloc *brfilter_user;
extern stralloc *cfilter_user;
extern stralloc *crfilter_user;
extern stralloc *pfilter_user;
extern stralloc *ufilter_user;
extern stralloc *ufilter_md5_user;
extern stralloc *ufilter_sha1_user;
extern stralloc *urfilter_user;
extern stralloc *wfilter_user;
extern stralloc *wrfilter_user;

/* information for redirected sites */
extern stralloc clamav; /* current version of clamav */
extern stralloc filter; /* some filter description, eg. failed words */
extern stralloc virus;  /* name of virus */

/* destination websites for squid */
extern char *redir_badurl;
extern char *redir_badcont;
extern char *redir_baduser;
extern char *redir_badhost;
extern char *redir_safesite;
extern char *redir_virusfound;
extern char *redir_bannerfound;
extern char *redir_webinterface;

/* misc directories */
extern char *host_dir;
extern char *user_dir;
extern char *redir_dir;
extern char *bfilter_dir;
extern char *bcfilter_dir;
extern char *brfilter_dir;
extern char *cfilter_dir;
extern char *crfilter_dir;
extern char *pfilter_dir;
extern char *ufilter_dir;
extern char *ufilter_md5_dir;
extern char *ufilter_sha1_dir;
extern char *urfilter_dir;
extern char *wfilter_dir;
extern char *wrfilter_dir;

/* clamd socket */
extern char *clamav_socket;

/* decoded infos */
extern stralloc ip;
extern stralloc url;
extern stralloc host;
extern stralloc user;
extern stralloc method;
extern stralloc redirsite;

/* panic.c */
extern int panic(char *msg);

/* check_...c */
extern int check_redirect(void);
extern int check_host(int *todo);
extern int check_user(int *todo);
extern int check_blist(void);
extern int check_wlist(void);
extern int check_banner(void);
extern int check_cont(int todo);

/* clamav routines */
extern int check_clamav_connect(void);
extern int check_clamav_checkresult(void);
extern void check_clamav_put2stream(char ch);

/* case_strstr.c -> 1=>found | 0=>not found */
extern int case_strstr(const char *haystack, const char *needle);

/* redir_site.c */
#define REDIR_TYPE_USER    0 /* user not okay */
#define REDIR_TYPE_HOST    1 /* host not okay */
#define REDIR_TYPE_URL     2 /* url not okay */
#define REDIR_TYPE_CONT    4 /* content not okay */
#define REDIR_TYPE_VIRUS   8 /* virus found */
#define REDIR_TYPE_BANNER 16 /* banner found */
#define REDIR_TYPE_CONFIG 32 /* webinterface */
extern void redir_site(int type);

#define isset(v,x)     (((v)&(x)) == (x))
#define set(v,x)       (v) |=  (x)
#define unset(v,x)     (v) &= ~(x)

/* read_acls.c */
extern void read_acls(void);

/* array's of type struct squidwall_regex */
extern array array_bcfilter_todo;
extern array array_cfilter_todo;
extern array array_pfilter_todo;

/* read_filters.c */
extern void read_filters(struct squidwall_acl *acl, const char *path, const char *file);

#endif
